Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPiotr Przybylski <piotrprz@gmail.com>2011-06-17 02:22:25 +0400
committerPiotr Przybylski <piotrprz@gmail.com>2011-06-17 02:22:25 +0400
commit12f70e8938cd9e3c76e878669d3de4bf4cb725ec (patch)
tree32e2fb534d8497a16d7b01008bb9fb8ae874cb32 /tbl_printview.php
parentd607fa3e5cca1bd9c8e1817db81e9a281cf68610 (diff)
Replace all SHOW FIELDS calls with PMA_DBI_get_columns() or PMA_DBI_get_columns_sql()
Fix PMA_DBI_get_columns() in Drizzle when $full == false
Diffstat (limited to 'tbl_printview.php')
-rw-r--r--tbl_printview.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/tbl_printview.php b/tbl_printview.php
index 7f97e80168..9ade6035bf 100644
--- a/tbl_printview.php
+++ b/tbl_printview.php
@@ -99,13 +99,13 @@ foreach ($the_tables as $key => $table) {
* Gets fields properties
*/
$result = PMA_DBI_query(
- 'SHOW FIELDS FROM ' . PMA_backquote($table) . ';', null,
+ PMA_DBI_get_columns_sql($db, $table), null,
PMA_DBI_QUERY_STORE);
$fields_cnt = PMA_DBI_num_rows($result);
// We need this to correctly learn if a TIMESTAMP is NOT NULL, since
// SHOW FULL FIELDS or INFORMATION_SCHEMA incorrectly says NULL
// and SHOW CREATE TABLE says NOT NULL (tested
// in MySQL 4.0.25 and 5.0.21, http://bugs.mysql.com/20910).
@@ -198,7 +198,7 @@ foreach ($the_tables as $key => $table) {
}
$field_name = htmlspecialchars($row['Field']);
// here, we have a TIMESTAMP that SHOW FULL FIELDS reports as having the
// NULL attribute, but SHOW CREATE TABLE says the contrary. Believe
// the latter.
/**
@@ -99,13 +99,13 @@ foreach ($the_tables as $key => $table) {
$fields_cnt = PMA_DBI_num_rows($result);
// We need this to correctly learn if a TIMESTAMP is NOT NULL, since
-// SHOW FULL FIELDS or INFORMATION_SCHEMA incorrectly says NULL
+// SHOW FULL COLUMNS or INFORMATION_SCHEMA incorrectly says NULL
// and SHOW CREATE TABLE says NOT NULL (tested
// in MySQL 4.0.25 and 5.0.21, http://bugs.mysql.com/20910).
@@ -198,7 +198,7 @@ foreach ($the_tables as $key => $table) {
}
$field_name = htmlspecialchars($row['Field']);
- // here, we have a TIMESTAMP that SHOW FULL FIELDS reports as having the
+ // here, we have a TIMESTAMP that SHOW FULL COLUMNS reports as having the
// NULL attribute, but SHOW CREATE TABLE says the contrary. Believe
// the latter.